@@ -750,6 +750,7 @@ gsm_properties_dialog_class_init (GsmPropertiesDialogClass *klass)
 static void
 gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
 {
+        GtkWidget   *content_area;
         GtkWidget   *widget;
         GConfClient *client;
         GError      *error;
@@ -778,13 +779,14 @@ gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
                 }
         }
 
+        content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
         widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
                                                      "main-notebook"));
-        gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), widget);
+        gtk_container_add (GTK_CONTAINER (content_area), widget);
 
         gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+        gtk_box_set_spacing (GTK_BOX (content_area), 2);
         gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
         gtk_window_set_icon_name (GTK_WINDOW (dialog), "session-properties");
         gtk_window_set_title (GTK_WINDOW (dialog), _("Startup Applications Preferences"));
